Learn R Programming

excursions (version 2.0.6)

contourmap.colors: Define a color map for displaying contour maps.

Description

contourmap.colors calculates suitable colours for displaying contour maps.

Usage

contourmap.colors(lp,
                  zlim,
                  col,
                  credible.col)

Arguments

lp
A contourmap calculated by contourmap.
zlim
The range that should be used (optional). The default is the range of the mean value function used when creating the contourmap.
col
The colormap that the colours should be taken from.
credible.col
The color that should be used for displaying the credible regions for the contour curves (optional).

Value

  • A color map.

Examples

Run this code
n = 100
  Q = Matrix(toeplitz(c(1, -0.5, rep(0, n-2))))
  map <- contourmap(mu = seq(-5, 5, length=n),Q,n.levels = 2)
  cols = contourmap.colors(map, col=heat.colors(100, 1),
                           credible.col = grey(0.5, 1))

Run the code above in your browser using DataLab