excursions.variances: Calculate variances from a sparse precision matrix
Description
excursions.variances calculates the diagonal of the inverse of a sparse symmetric positive definite matrix Q. The method for calculating the diagonal requires the Cholesky factor of Q, which should be supplied if available.
Usage
excursions.variances(L,Q,max.threads=0)
Arguments
L
Cholesky factor of precision matrix.
Q
Precision matrix.
max.threads
Decides the number of threads the program can use. Set to 0 for using the maximum number of threads allowed by the system (default).
## Create a tridiagonal precision matrixn = 21Q = Matrix(toeplitz(c(1, -0.1, rep(0, n-2))))
v2 = excursions.variances(Q=Q,max.threads=2)
## var2 should be the same as:v1 = diag(solve(Q))